@@ -27,8 +27,8 @@ import java.util.Optional;
 import org.guvnor.common.services.project.model.Module;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.project.security.ProjectPermissionsService;
-import org.guvnor.structure.contributors.Contributor;
-import org.guvnor.structure.contributors.ContributorType;
+import org.uberfire.security.Contributor;
+import org.uberfire.security.ContributorType;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.organizationalunit.config.BranchPermissions;
 import org.guvnor.structure.organizationalunit.config.RolePermissions;
@@ -52,11 +52,10 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.eq;
-import static org.mockito.Matchers.same;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.ArgumentMatchers.same;
 import static org.mockito.Mockito.anyList;
-import static org.mockito.Mockito.anyString;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
@@ -628,11 +627,11 @@ public class ProjectControllerTest {
     }
 
     @Test
-    public void userCannotSubmitChangeRequestWhenInMasterBranchTest() {
+    public void userCannotSubmitChangeRequestWhenInDefaultBranchTest() {
         WorkspaceProject project = mock(WorkspaceProject.class);
-        Branch master = mock(Branch.class);
-        doReturn("master").when(master).getName();
-        doReturn(master).when(project).getBranch();
+        Branch defaultBranch = mock(Branch.class);
+        doReturn("master").when(defaultBranch).getName();
+        doReturn(defaultBranch).when(project).getBranch();
 
         projectController.canSubmitChangeRequest(project).then(userCanSubmitChangeRequest -> {
             assertFalse(userCanSubmitChangeRequest);
